@@ -2,6 +2,7 @@
  *  Authors: Rodney Dawes <dobey@ximian.com>
  *
  *  Copyright 2004-2007 Novell, Inc. (www.novell.com)
+ *  Copyright 2008-2009 Rodney Dawes
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -21,6 +22,7 @@
 #include <config.h>
 
 #include <libbonobo.h>
+#include <libgnome/gnome-init.h>
 
 #include "evolution-webcal-main.h"
 
@@ -262,7 +264,7 @@ gint main (gint argc, gchar ** argv) {
 
   g_thread_init (NULL);
   program = gnome_program_init ("evolution-webcal", VERSION,
-				LIBGNOMEUI_MODULE,
+				LIBGNOME_MODULE,
 				argc, argv,
 				GNOME_PARAM_GOPTION_CONTEXT, ctx,
 				NULL);
