@@ -2,6 +2,7 @@
  *  Authors: Rodney Dawes <dobey@ximian.com>
  *
  *  Copyright 2004-2007 Novell, Inc. (www.novell.com)
+ *  Copyright 2008-2009 Rodney Dawes
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -19,7 +20,6 @@
  */
 
 #include <config.h>
-#include <gdk/gdkcolor.h>
 #include <libbonobo.h>
 
 #include "evolution-webcal-notify.h"
@@ -38,7 +38,7 @@
 typedef struct {
   GtkWidget * dialog;
   GtkWidget * image;
-  GnomeIconTheme * theme;
+  GtkIconTheme * theme;
 } EIcalShareDialog;
 
 enum {
@@ -83,18 +83,11 @@ static void e_webcal_label_handle_resize (GtkWidget * label,
 		    G_CALLBACK (e_webcal_label_size_allocate_cb), label);
 }
 
-static void e_webcal_icon_theme_changed (GnomeIconTheme * theme,
+static void e_webcal_icon_theme_changed (GtkIconTheme * theme,
 					 EIcalShareDialog * dialog) {
-  gchar * icofile;
-
-  icofile = gnome_icon_theme_lookup_icon (dialog->theme, "x-office-calendar",
-					  48, NULL, NULL);
-
-  if (icofile != NULL) {
-    gtk_window_set_default_icon_from_file (icofile, NULL);
-    gtk_image_set_from_file (GTK_IMAGE (dialog->image), icofile);
-  }
-  g_free (icofile);
+  gtk_window_set_default_icon_name ("x-office-calendar");
+  gtk_image_set_from_icon_name (GTK_IMAGE (dialog->image),
+				"x-office-calendar", GTK_ICON_SIZE_DIALOG);
 }
 
 static void e_webcal_change_adjustment (GtkMenuShell * shell,
@@ -251,7 +244,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   GtkWidget * label, * button;
   SoupURI * tmpuri;
   gchar * tmpname;
-  gchar * icofile, * mrkname, * ref_str;
+  gchar * mrkname, * ref_str;
   gint ref_timeout, ref_multi;
   ESource * source;
   ESourceGroup * events_group = NULL;
@@ -348,8 +341,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
 
   dialog = g_new0 (EIcalShareDialog, 1);
 
-  dialog->theme = gnome_icon_theme_new ();
-  gnome_icon_theme_set_allow_svg (dialog->theme, TRUE);
+  dialog->theme = gtk_icon_theme_get_default ();
 
   g_signal_connect (G_OBJECT (dialog->theme), "changed",
 		    G_CALLBACK (e_webcal_icon_theme_changed), dialog);
@@ -360,12 +352,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog->dialog), FALSE);
   gtk_window_set_default_size (GTK_WINDOW (dialog->dialog), 376, 144);
 
-  icofile = gnome_icon_theme_lookup_icon (dialog->theme,
-					  "x-office-calendar",
-					  48, NULL, NULL);
-  if (icofile != NULL) {
-    gtk_window_set_default_icon_from_file (icofile, NULL);
-  }
+  gtk_window_set_default_icon_name ("x-office-calendar");
 
   gtk_widget_realize (dialog->dialog);
 
@@ -421,7 +408,8 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   gtk_widget_show (vbox);
 
   /* Pretty icon */
-  dialog->image = gtk_image_new_from_file (icofile);
+  dialog->image = gtk_image_new_from_icon_name ("x-office-calendar",
+						GTK_ICON_SIZE_DIALOG);
   gtk_box_pack_start (GTK_BOX (vbox), dialog->image, FALSE, FALSE, 0);
   gtk_widget_show (dialog->image);
 
@@ -534,7 +522,6 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
 
   gtk_label_set_mnemonic_widget (GTK_LABEL (clabel), cbutton);
 
-  g_free (icofile);
   g_free (tmpname);
   soup_uri_free (tmpuri);
 
@@ -591,7 +578,6 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
     g_object_unref (tasks_sources);
     g_object_unref (source);
 
-    g_object_unref (dialog->theme);
     gtk_widget_destroy (dialog->dialog);
     break;
   }
