@@ -1,7 +1,8 @@
 /*
  *  Authors: Rodney Dawes <dobey@ximian.com>
  *
- *  Copyright 2004 Novell, Inc. (www.novell.com)
+ *  Copyright 2004-2007 Novell, Inc. (www.novell.com)
+ *  Copyright 2008-2009 Rodney Dawes
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -22,9 +23,7 @@
 #define _E_WEBCAL_NOTIFY_H_
 
 #include <libecal/e-cal.h>
-#include <gnome.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-icon-theme.h>
 #include <libsoup/soup.h>
 
 void e_webcal_display_error (const gchar * title, const gchar * message,
